From: Felix Moessbauer <felix.moessbauer@siemens.com>
To: <isar-users@googlegroups.com>
Cc: <henning.schild@siemens.com>, <adriaan.schmidt@siemens.com>,
<jan.kiszka@siemens.com>,
Felix Moessbauer <felix.moessbauer@siemens.com>
Subject: [PATCH 2/4] Add ISAR version of biosplusefi WIC plugin
Date: Fri, 4 Mar 2022 16:25:51 +0100 [thread overview]
Message-ID: <20220304152553.584534-3-felix.moessbauer@siemens.com> (raw)
In-Reply-To: <20220304152553.584534-1-felix.moessbauer@siemens.com>
This patch adds support to create a disk image that works with both
EFI and legacy bios. The biosplusefi-isar is based on the original
biosplusefi WIC plugin that internally calls the bootimg-pcbios and
bootimg-efi. By that, code duplication can be avoided.
The generated image can be booted with EFI or legacy pcbios.
Signed-off-by: Felix Moessbauer <felix.moessbauer@siemens.com>
---
.../source/bootimg-biosplusefi-isar.py | 24 +++++++------------
1 file changed, 8 insertions(+), 16 deletions(-)
diff --git a/meta/scripts/lib/wic/plugins/source/bootimg-biosplusefi-isar.py b/meta/scripts/lib/wic/plugins/source/bootimg-biosplusefi-isar.py
index 5bd73906..6bb15cd9 100644
--- a/meta/scripts/lib/wic/plugins/source/bootimg-biosplusefi-isar.py
+++ b/meta/scripts/lib/wic/plugins/source/bootimg-biosplusefi-isar.py
@@ -1,22 +1,14 @@
#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# Imported from openembedded-core
#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# SPDX-License-Identifier: GPL-2.0-only
#
# DESCRIPTION
# This implements the 'bootimg-biosplusefi' source plugin class for 'wic'
#
# AUTHORS
# William Bourque <wbourque [at) gmail.com>
+# Felix Moessbauer <felix.moessbauer (at] siemens.com>
import types
@@ -75,10 +67,10 @@ class BootimgBiosPlusEFIPlugin(SourcePlugin):
--ondisk sda --label os_boot --active --align 1024 --use-uuid
"""
- name = 'bootimg-biosplusefi'
+ name = 'bootimg-biosplusefi-isar'
- __PCBIOS_MODULE_NAME = "bootimg-pcbios"
- __EFI_MODULE_NAME = "bootimg-efi"
+ __PCBIOS_MODULE_NAME = "bootimg-pcbios-isar"
+ __EFI_MODULE_NAME = "bootimg-efi-isar"
__imgEFIObj = None
__imgBiosObj = None
@@ -106,7 +98,7 @@ class BootimgBiosPlusEFIPlugin(SourcePlugin):
loader = SourceFileLoader(cls.__PCBIOS_MODULE_NAME, modulePath)
mod = types.ModuleType(loader.name)
loader.exec_module(mod)
- cls.__imgBiosObj = mod.BootimgPcbiosPlugin()
+ cls.__imgBiosObj = mod.BootimgPcbiosIsarPlugin()
# Import bootimg-efi (class name "BootimgEFIPlugin")
modulePath = os.path.join(os.path.dirname(os.path.realpath(__file__)),
@@ -1,22 +1,14 @@
#
# DESCRIPTION
-# This implements the 'bootimg-biosplusefi' source plugin class for 'wic'
+# This implements the 'bootimg-biosplusefi-isar' source plugin class for 'wic'
#
# AUTHORS
--
2.30.2
next prev parent reply other threads:[~2022-03-04 15:26 UTC|newest]
Thread overview: 10+ messages / expand[flat|nested] mbox.gz Atom feed top
2022-03-04 15:25 [PATCH 0/4] Add support for dual bios + efi disk generation Felix Moessbauer
2022-03-04 15:25 ` [PATCH 1/4] Copy efi-plus-pcbios script from OE Felix Moessbauer
2022-03-04 15:25 ` Felix Moessbauer [this message]
2022-03-04 16:33 ` [PATCH 2/4] Add ISAR version of biosplusefi WIC plugin Henning Schild
2022-03-04 15:25 ` [PATCH 3/4] wic: biosplusefi: make sure sub-plugins can import isarpluginbase Felix Moessbauer
2022-03-04 16:34 ` Henning Schild
2022-03-04 15:25 ` [PATCH 4/4] test: add target for efi-plus-pcbios image type Felix Moessbauer
2022-03-04 16:41 ` Henning Schild
2022-03-04 21:28 ` Henning Schild
2022-03-04 21:26 ` [PATCH 0/4] Add support for dual bios + efi disk generation Henning Schild
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20220304152553.584534-3-felix.moessbauer@siemens.com \
--to=felix.moessbauer@siemens.com \
--cc=adriaan.schmidt@siemens.com \
--cc=henning.schild@siemens.com \
--cc=isar-users@googlegroups.com \
--cc=jan.kiszka@siemens.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox